# README

# TabNet : Attentive Interpretable Tabular Learning


* this is maintained fork version of [dreamquark-ai/tabnet](https://github.com/dreamquark-ai/tabnet) with some changes and improvements.

* it uses pytorch metrics instead of numpy metrics, and also enhanced predictions & evaluation for GPU CUDA enhancement.

* expect more changes in the future.

* for the record and license policy assume everything is changed.

* **thanks & credits to dreamquark-ai team for the implementation and research.**

This is a pyTorch implementation of Tabnet (Arik, S. O., & Pfister, T. (2019). TabNet: Attentive Interpretable Tabular Learning. arXiv preprint arXiv:1908.07442.) https://arxiv.org/pdf/1908.07442.pdf. Please note that some different choices have been made overtime to improve the library which can differ from the orginal paper.
